/**
* Klasse SFServerExec
* SchiffsFracht Dispositionsprogramm
* Startet ein Server
*/

import java.net.*;
import java.rmi.*;


public class SFServerExec
{
	private static void usage()
	{
		System.err.println("usage: java SFServerImpl <type> <desc>");
		System.err.println("   type: (port|carrier|customs) select type of server");
		System.err.println("   desc: description of server, e. g. \"Wien Freudenauer Hafen\"");
//		System.err.println("   regserv: hostname of registryserver. default = " + SFServerImpl.regServer);
	}

	public static void main(String[] argv)
	{
		CommandLineInterface	cli;
//		ServerMap	serverMap = new ServerMap();
		SFServerImpl	obj = null;
		String		server = Config.getInstance().get("hostname").toString();
//		String		regServ = null;
		String		desc = "";
		int		type = 0, i;

		if ((argv.length < 2) || (argv.length > 3))
		{
			usage();
			System.exit(1);
		}

		// Servertyp identifiziren
		if (argv[0].compareToIgnoreCase("carrier") == 0)
			type = ServerInfo.CARRIER;
		else if (argv[0].compareToIgnoreCase("customs") == 0)
			type = ServerInfo.CUSTOMS;
		else if (argv[0].compareToIgnoreCase("port") == 0)
			type = ServerInfo.PORT;
		else
		{
			System.err.println("*** ERROR: unknown servertype");
			usage();
			System.exit(1);
		}

/*		if (argv.length == 3)
			regServ = argv[2];*/

		// use a Security Manager
		if (System.getSecurityManager() == null)
			System.setSecurityManager(new RMISecurityManager());

		/* Hostname des Rechners holen. */
		if (Config.getInstance().get("hostdetect").attrBoolValue)
		{
			try
			{
				server = InetAddress.getLocalHost().getCanonicalHostName();
			}
			catch (Exception e)
			{
				System.err.println("*** ERROR: could not determine local hostname");
				System.exit(1);
			}
		}

		/* MessageServer RMI-Object instantiieren. */
		if ((obj = SFServerImpl.getInstance(server, argv[1], type)) == null)
			System.exit(1);

		cli = new CommandLineInterface(obj.getServerInfo().getSrvNum() + ":" + obj.getServerInfo().getTypeStr() + ":" + obj.getServerInfo().getDescription() + "# ");
		cli.registerCommand("servers", obj.getServerMap());
		cli.registerCommand("list", obj.getFreightMap());
		cli.registerCommand("config", Config.getInstance());
		cli.registerCommand("info", obj.getServerInfo());
	
		obj.initCmd(cli);

		/* Konsole starten */
		obj.logConsole("Server ready, starting Console");
		cli.startCLI();

		obj.unregister();

		System.exit(0);
	}
}
