/**
* Klasse CommandLineInterface
* SchiffsFracht Dispositionsprogramm
*/

import java.util.*;
import java.io.*;


public class CommandLineInterface implements Command
{
	private HashMap	cmdMap;
	private boolean	running;
	private String	prompt;

	/** Neue HashMap wird initialisiert und
	  * befehle exit, quit, help, ? wird registriert
	  */
	public CommandLineInterface(String p)
	{
		this.prompt = p;
		this.cmdMap = new HashMap();
		this.running = true;
		this.registerCommand("exit", this);
		this.registerCommand("quit", this);
		this.registerCommand("help", this);
		this.registerCommand("?", this);
	}

	/** cmd wird in HashMap hinzugefuegt */
	public void registerCommand(String cmdString, Command cmd)
	{
		this.cmdMap.put(cmdString.toLowerCase(), cmd);
	}

	/** Diese Methode parsed einen Inputstring und fhrt
	  * gegebenenfalls den entsprechenden Befehl aus.
	  * @param String : InputString = "<command> [<param1> [<param2> ... [<paramN>]]]"
	  */
	public int parseString(String input)
	{
		String		cmdString;
		String		paramString;
		StringTokenizer	t;
		Command		cmd;


		t = new StringTokenizer(input, " ");

		if (!t.hasMoreTokens())
			return(Command.OK);

		cmdString = t.nextToken();
		if ((cmd = (Command) this.cmdMap.get(cmdString.toLowerCase())) == null)
			return(Command.UNKNOWNCMD);

		paramString = "";
		while (t.hasMoreTokens())
			paramString += t.nextToken() + " ";

		return(cmd.execute(new PrintWriter(System.out, true), cmdString, paramString));
	}

	/** Mit dieser Methode startet man CommandLineInterface
	  * While Schleife, solange running = true
	  */
	public void startCLI()
	{
		BufferedReader	in;
		String		lineBuf;

		in = new BufferedReader(new FileReader(FileDescriptor.in));

		System.out.print(this.prompt);
		while (this.running && ((lineBuf = this.readLine(in)) != null))
			switch (this.parseString(lineBuf))
			{
				case Command.EXIT :
					System.out.println("*** GOOD BYE!");
					this.running = false;
					break;
				case Command.SYNTAXERROR :
					System.out.println("*** SYNTAX ERROR");
					System.out.print(this.prompt);
					break;
				case Command.UNKNOWNCMD :
					System.out.println("*** UNKNOWN COMMAND \"" + lineBuf.trim() + "\"");
					System.out.print(this.prompt);
					break;
				case Command.FINERROR :
					System.out.println("*** COMMAND COULD NOT BE FINISHED");
					System.out.print(this.prompt);
					break;
				default :
					System.out.print(this.prompt);
			}
	}

	public int execute(PrintWriter out, String cmdString, String paramString)
	{
		int	j;

		if ((cmdString.compareToIgnoreCase("exit") == 0) || (cmdString.compareToIgnoreCase("quit") == 0))
			return(Command.EXIT);

		if ((cmdString.compareToIgnoreCase("help") == 0) || (cmdString.compareToIgnoreCase("?") == 0))
		{
			j = 0;
			Iterator i = cmdMap.keySet().iterator();
			while (i.hasNext())
			{
				System.out.println((String) i.next());
				j++;
			}
			System.out.println(j + " commands available.");
			return(Command.OK);
		}

		return(Command.UNKNOWNCMD);
	}

	private String readLine(BufferedReader in)
	{
		try
		{
			return(in.readLine());
		}
		catch (Exception e)
		{
			return(null);
		}
	}
}
