import java.util.*;
import java.io.*;

/** Diese Klasse dient zur Verwaltung des Konfigurationsfiles.
  * Das Configfile "sf.conf" wird automatisch nach Erzeugung
  * einer einzigen Instanz eingelesen, und die Paramter zur Verfgung gestellt.
  * @author Bernhard Fiser
  * @version 1.2 2002/10/09 */
public class Config extends HashMap implements Command
{
	private String[]	defaultValuePair = {"registry 62.178.240.184",
							"hostname localhost",
							"hostdetect true",
						    "errorlog sfdispo_error.log"};
	private static Config	config = null;

	private Config()
	{
		this.setDefault();
		this.read();
		this.addValuePair("version SFDispo V0.3-alpha, Bernhard R. Fiser, 2002", 0);
	}

	/** Instanz der Configklasse besorgen. Es exisitert
	  * immer nur eine Instanz, da der Constructor private
	  * deklariert ist. Das Configfile wird beim ersten
	  * Aufruf von getInstance() automatisch geladen. */
	public static Config getInstance()
	{
		if (config == null)
			config = new Config();
		return(config);
	}

	/** Gibt ein ValuePair Objekt das zu String s
	  * korreliert zurck
	  * @param String : Configstring
	  * @return ValuePair : null, falls kein passendes Objekt existiert. */
	public ValuePair get(String s)
	{
		return((ValuePair) super.get(s));
	}

	private void setDefault()
	{
		int	i;

		for (i = 0; i < this.defaultValuePair.length; i++)
			this.addValuePair(this.defaultValuePair[i], i);
	}

	private void read()
	{
		int		lineno = 0;
		String		s;
		ReadFile	in = new ReadFile();
		ValuePair	vp;

		if (!in.open("sf.conf"))
		{
			System.err.println("*** WARNING: Kein Configfile gefunden, verwende Defaultwerte.");
			return;
		}

		while((s = in.readLine()) != null)
		{
			lineno++;
			if (in.isEmpty(s))
				continue;
			if (in.isComment(s))
				continue;
			this.addValuePair(s, lineno);
		}
		in.close();
	}

	private boolean addValuePair(String s, int lineno)
	{
		ValuePair vp = new ValuePair();
		if (!vp.parseString(s))
		{
			System.err.println("*** WARNING: Syntaxerror im Configfile in Zeile " + lineno);
			return(false);
		}
		if (!vp.checkType())
		{
			System.err.println("*** WARNING: " + vp.errorString());
			return(false);
		}
		this.put(vp.attrName, vp);
		return(false);
	}

	public int execute(PrintWriter out, String cmdString, String paramString)
	{
		ValuePair	vp;
		Iterator	it;

		out.println("Configuration");
		it = this.values().iterator();
		while (it.hasNext())
		{
			vp = (ValuePair) it.next();
			out.println(vp.attrName + "\t" + vp);
		}
		return(Command.OK);
	}
}
