import java.rmi.*;
import java.rmi.server.*;
import java.util.*;
import java.io.*;


public class CustomsImpl extends SFServerImpl implements Customs, Command
{
	private final int	NUMPARAMS = 1;
	private final String	USAGE = "<freight#>\n sign papers for <freight#>.";

	public CustomsImpl(String host, String desc) throws RemoteException, AlreadyBoundException
	{
		super(host, desc, ServerInfo.CUSTOMS);
	}

	public void initCmd(CommandLineInterface cli)
	{
		cli.registerCommand("sign", this);
		cli.registerCommand("release", new CmdReleaseFreight(this));
	}

	public boolean requestPapers(FreightEntry entry) throws RemoteException
	{
		/* Status testen und erhhen und speichern. */
		if (!this.testAndRaise(FreightEntry.INIT, entry))
			return(false);

		this.logConsole("freightEntry " + entry.getFreightNum() + " is requested to sign");
		return(true);
	}

	public boolean setArrival(FreightEntry entry) throws RemoteException
	{
		/* Status testen und erhhen und speichern. */
		if (!this.testAndRaise(FreightEntry.ANNOUNCED, entry))
			return(false);

		this.logConsole("freightEntry " + entry.getFreightNum() + " is requested to check and release");
		return(true);
	}
	/** Fracht unterschreiben und digital signieren */
	public int execute(PrintWriter out, String cmdString, String paramString)
	{
		FreightEntry	freight;
		String		p[] = new String[NUMPARAMS];
		int		f = 0;
		int		tcount = 0;
		StringTokenizer	st = new StringTokenizer(paramString, " ");

		while (st.hasMoreTokens() && (tcount < NUMPARAMS))
			p[tcount++] = st.nextToken();

		if ((tcount != NUMPARAMS) || (p[0].equals("?")))
		{
			out.println(cmdString + " " + USAGE);
			return(Command.OK);
		}

		try
		{
			f = Integer.parseInt(p[0]);
		}
		catch (NumberFormatException e)
		{
			return(Command.SYNTAXERROR);
		}

		if ((freight = this.freightMap.get(f)) == null)
		{
			out.println("*** FreightEntry #" + f + " does not exist.");
			return(Command.OK);
		}

		if (freight.getState() != FreightEntry.SGNREQUEST)
		{
			out.println("*** FreightEntry #" + f + " has not been requested to sign.");
			return(Command.OK);
		}

		if (!freight.sign(this.sInfo.getSrvNum(), this.keyPair.getPrivate()))
		{
			out.println("*** FreightEntry #" + f + " could not be signed.");
		}
		//Wenn erfolgreich unterschrieben wird Frachtpapier zurueck an Reederei geschickt
		else {
			Carrier obj = null;
			int svr;
			ServerInfo sInfo;

			//Servernummer von Reederei finden = erste 4 ziffer von FreightNum
			svr = freight.getFreightNum() / 1000;
			sInfo = serverMap.get(svr);

			try {
				obj = (Carrier) Naming.lookup(ServerMap.getRmiString(sInfo));
				obj.grantPapers(freight);
				this.freightMap.remove(freight);
			}
			catch (Exception e) {
				// Fehler noch einbauen...
			}
		}

		return(Command.OK);
	}
}

